@@ -4,7 +4,7 @@
 modname = 'vcsfile'
 distname = "cubicweb-%s" % modname
 
-numversion = (1, 14, 0)
+numversion = (1, 15, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -19,7 +19,7 @@ classifiers = [
            'Programming Language :: JavaScript',
            ]
 
-__depends__ = {'cubicweb': '>= 3.15.6',
+__depends__ = {'cubicweb': '>= 3.16',
                'cubicweb-localperms': '>= 0.1.0',
                'logilab-mtconverter': '>= 0.7.0',
                'logilab-common': '>= 0.59.0'
