@@ -16,7 +16,7 @@ from logilab.common.modutils import LazyObject
 from logilab.mtconverter import guess_mimetype_and_encoding
 from yams import ValidationError
 
-from cubicweb import Binary, QueryError, typed_eid
+from cubicweb import Binary, QueryError
 from cubes.vcsfile import queries
 
 _VCSTYPES = {'subversion': LazyObject('cubes.vcsfile.reposvn', 'SVNRepository'),
@@ -246,7 +246,7 @@ class VCSStorage(storages.Storage):
 
     def callback(self, source, session, value):
         repoeid, dir, name, revnum = source.binary_to_str(value).split('\x01')
-        repoeid = typed_eid(repoeid)
+        repoeid = int(repoeid)
         try:
             vcsrepohdlr = repository_handler(session.entity_from_eid(repoeid, 'Repository'))
         except Exception, ex:
