@@ -36,6 +36,6 @@ class VCSRefreshCommand(Command):
         ## two hg repo with the same source_url
         for hgrepo, source_url in rset:
             print 'refreshing', source_url
-            cnx.call_service('refresh_repository', async=False, eids=hgrepo)
+            cnx.call_service('refresh_repository', eids=hgrepo)
 
 CWCTL.register(VCSRefreshCommand)
