@@ -80,10 +80,6 @@ class Repository(AnyEntity):
                 'type': self.type, 'eid': self.eid}
         return title
 
-    def cw_clear_all_caches(self):
-        super(Repository, self).cw_clear_all_caches()
-        clear_cache(self, 'branch_head')
-
     def printable_value(self, attr, *args, **kwargs):
         if attr == 'source_url':
             if args:
@@ -124,17 +120,16 @@ class Repository(AnyEntity):
             branches = [self.default_branch()]
         return branches
 
-    @cached
-    def branch_head(self, branch=_MARKER):
+    def branch_head(self, branch=_MARKER, public_only=False):
         """return latest revision of the given branch"""
         if branch is _MARKER:
             branch = self.default_branch()
-        rset = self._cw.execute(
-            'Any REV WHERE REV from_repository R, R eid %(r)s, REV revision RR '
+        rql = (
+            'Any REV WHERE REV from_repository R, R eid %%(r)s, REV revision RR '
             'WITH RR BEING (Any MAX(RR) WHERE '
-            '  REV from_repository R, R eid %(r)s, REV branch %(branch)s, '
-            '  REV revision RR)',
-            {'r': self.eid, 'branch': branch})
+            '  REV from_repository R, R eid %%(r)s, REV branch %%(branch)s, '
+            '  REV revision RR%s)' % (', REV phase "public"' if public_only else ''))
+        rset = self._cw.execute(rql, {'r': self.eid, 'branch': branch})
         if not rset:
             return None
         return rset.get_entity(0, 0)
@@ -275,7 +270,6 @@ class VersionedFile(AnyEntity):
     def cw_clear_all_caches(self):
         super(VersionedFile, self).cw_clear_all_caches()
         clear_cache(self, 'version_content')
-        clear_cache(self, 'branch_head')
 
     # navigation in versioned content #########################################
 
@@ -321,19 +315,19 @@ class VersionedFile(AnyEntity):
             return rset.get_entity(0, 0)
         return None
 
-    @cached
-    def branch_head(self, branch=_MARKER):
+    def branch_head(self, branch=_MARKER, public_only=False):
         """return latest [deleted] version content for this file in the given
         branch
         """
         if branch is _MARKER:
             branch = self.repository.default_branch()
-        rset = self._cw.execute(
-            'Any V WHERE X eid %(x)s, V content_for X, V at_revision R, '
+        rql = (
+            'Any V WHERE X eid %%(x)s, V content_for X, V at_revision R, '
             'R revision RR WITH RR BEING '
-            '(Any MAX(RR) WHERE X eid %(x)s, V content_for X, V at_revision R, '
-            ' R branch %(branch)s, R revision RR)',
-            {'x': self.eid, 'branch': branch})
+            '(Any MAX(RR) WHERE X eid %%(x)s, V content_for X, V at_revision R, '
+            ' R branch %%(branch)s, R revision RR%s)' %
+            (', R phase "public"' if public_only else ''))
+        rset = self._cw.execute(rql, {'x': self.eid, 'branch': branch})
         # content_for relation is not mandatory on VersionedFile entities
         if not rset:
             return None
