@@ -514,11 +514,19 @@ class HGTransaction(object):
             self.revision.cw_attr_cache.get('branch') or u'default')
         if branch != u'default':
             self.extra['branch'] = branch
-        try:
-            self.hgparent = p1 = self.repo.branchtags()[branch]
-        except KeyError:
-            # new branch
-            self.hgparent = p1 = self.repo.branchtags().get('default')
+        if getattr(self.repo, 'branchtags', None) is None:
+            # hg 2.9, branchtags is gone
+            try:
+                self.hgparent = p1 = self.repo.branchmap().branchtip(branch)
+            except KeyError:
+                # new branch
+                self.hgparent = p1 = self.repo.branchmap().branchtip('default')
+        else:
+            try:
+                self.hgparent = p1 = self.repo.branchtags()[branch]
+            except KeyError:
+                # new branch
+                self.hgparent = p1 = self.repo.branchtags().get('default')
         if p1:
             if not self.revision.parent_revision:
                 raise ValidationError(self.revision.eid,
