@@ -8,12 +8,9 @@ from cubes.vcsfile import bridge
 
 def init_vcsrepo(repo, commitevery=1):
     bridge._REPOHDLRS.clear()
-    session = repo.internal_session()
-    try:
+    with repo.internal_session(safe=True) as session:
         bridge.import_content(session, commitevery=commitevery,
                               raise_on_error=True)
-    finally:
-        session.close()
 
 class VCSRepositoryTC(CubicWebTC):
     """base class for test which should import a repository during setup"""
