@@ -13,9 +13,8 @@ from cubicweb import Unauthorized, tags
 from cubicweb.mttransforms import ENGINE
 from cubicweb.predicates import is_instance, score_entity
 from cubicweb.view import EntityView
-from cubicweb.web import uicfg
 from cubicweb.web.views import (ibreadcrumbs, idownloadable, tableview,
-                                baseviews, primary, tabs, navigation)
+                                baseviews, primary, tabs, navigation, uicfg)
 
 # primary view tweaks
 _pvs = uicfg.primaryview_section
